OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Pogrešna lozinka",
    "No user supplied" : "Nijedan korisnik nije dostavljen",
    "Authentication error" : "Pogrešna autentikacija",
    "Wrong admin recovery password. Please check the password and try again." : "Pogrešna admin lozinka za oporavak. Molimo provjerite lozinku i pokušajte ponovno.",
    "Unable to change password" : "Promjena lozinke nije moguća",
    "Couldn't send reset email. Please contact your administrator." : "Nije mogće poslati resetiranu poštu. MOlimo kontaktirajte svog administratora.",
    "Saved" : "Spremljeno",
    "test email settings" : "Postavke za testiranje e-pošte",
    "Email sent" : "E-pošta je poslana",
    "You need to set your user email before being able to send test emails." : "Prije nego li ste u mogućnosti slati testnu e-poštu trebate postaviti svoj korisnički email.",
    "Your full name has been changed." : "Vaše puno ime je promijenjeno.",
    "Unable to change full name" : "Puno ime nije moguće promijeniti.",
    "__language_name__" : "__jezik_naziv___",
    "Language changed" : "Promjena jezika",
    "Invalid request" : "Zahtjev neispravan",
    "Admins can't remove themself from the admin group" : "Administratori ne mogu sami sebe ukloniti iz admin grupe",
    "Unknown user" : "Korisnik nepoznat",
    "Couldn't remove app." : "Nije moguće ukloniti app.",
    "All" : "Sve",
    "Enabled" : "Aktivirano",
    "Please wait...." : "Molimo pričekajte...",
    "Error while disabling app" : "Pogreška pri onemogućavanju app",
    "Disable" : "Onemogućite",
    "Enable" : "Omogućite",
    "Error while enabling app" : "Pogreška pri omogućavanju app",
    "Updating...." : "Ažuriranje...",
    "Error while updating app" : "Pogreška pri ažuriranju app",
    "Updated" : "Ažurirano",
    "Uninstalling ...." : "Deinstaliranje....",
    "Error while uninstalling app" : "Pogreška pri deinstaliranju app",
    "Uninstall" : "Deinstalirajte",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Jeste li doista sigurni da želite dodati \"{domain}\" kao pouzdanu domenu?",
    "Add trusted domain" : "Dodajte pouzdanu domenu",
    "Valid until {date}" : "Valid until {date}",
    "Delete" : "Izbrišite",
    "Sending..." : "Slanje...",
    "Select a profile picture" : "Odaberite sliku profila",
    "Very weak password" : "Lozinka vrlo slaba",
    "Weak password" : "Lozinka slaba",
    "So-so password" : "Lozinka tako-tako",
    "Good password" : "Lozinka dobra",
    "Strong password" : "Lozinka snažna",
    "Groups" : "Grupe",
    "Unable to delete {objName}" : "Nije moguće izbrisati {objName}",
    "A valid group name must be provided" : "Nužno je navesti valjani naziv grupe",
    "deleted {groupName}" : "izbrisana {groupName}",
    "undo" : "poništite",
    "never" : "nikad",
    "deleted {userName}" : "izbrisano {userName}",
    "add group" : "dodajte grupu",
    "A valid username must be provided" : "Nužno je navesti valjano korisničko ime",
    "A valid password must be provided" : "Nužno je navesti valjanu lozinku",
    "Cheers!" : "Cheers!",
    "Forum" : "Forum",
    "Documentation:" : "Dokumentacija:",
    "Enable only for specific groups" : "Omogućite samo za specifične grupe",
    "Uninstall App" : "Deinstalirajte app",
    "Cron" : "Cron",
    "Cron was not executed yet!" : "Cron još nije izvršen!",
    "Execute one task with each page loaded" : "Izvršite jedan zadatak sa svakom učitanom stranicom",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php je registriran na webcron usluzi da poziva cron.php svakih 15 minuta preko http.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Koristite cron uslugu sustava za pozivanje cron.php datoteke svakih 15 minuta.",
    "Common Name" : "Common Name",
    "Valid until" : "Valid until",
    "Issued By" : "Issued By",
    "Valid until %s" : "Valid until %s",
    "Sharing" : "Dijeljenje zajedničkih resursa",
    "Allow apps to use the Share API" : "Dopustite apps korištenje Share API",
    "Allow users to share via link" : "Dopustite korisnicia dijeljenje putem veze",
    "Allow public uploads" : "Dopustite javno učitavanje sadržaja",
    "Enforce password protection" : "Nametnite zaštitu lozinki",
    "Set default expiration date" : "Postavite zadani datum isteka",
    "Allow users to send mail notification for shared files" : "Dopustite korisnicima slanje notifikacijske e-pošte za podijeljene datoteke",
    "Expire after " : "Istek nakon",
    "days" : "dana",
    "Enforce expiration date" : "Nametnite datum isteka",
    "Allow resharing" : "Dopustite ponovno dijeljenje zajedničkih resursa",
    "Restrict users to only share with users in their groups" : "Ograničite korisnike na meusobno dijeljenje resursa samo s korisnicima unutar svoje grupe",
    "Exclude groups from sharing" : "Isključite grupe iz dijeljenja zajedničkih resursa",
    "These groups will still be able to receive shares, but not to initiate them." : "Ove će grupe još uvijek moći primati dijeljene resurse, ali ne i inicirati ih",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Sve (kobni problemi, pogreške, upozorenja, ispravljanje pogrešaka)",
    "Info, warnings, errors and fatal issues" : "Informacije, upozorenja, pogreške i kobni problemi",
    "Warnings, errors and fatal issues" : "Upozorenja, pogreške i kobni problemi",
    "Errors and fatal issues" : "Pogreške i kobni problemi",
    "Fatal issues only" : "Samo kobni problemi",
    "Log" : "Zapisnik",
    "None" : "Ništa",
    "Login" : "Prijava",
    "Plain" : "Čisti tekst",
    "NT LAN Manager" : "NT LAN Manager",
    "This is used for sending out notifications." : "Ovo se koristi za slanje notifikacija.",
    "Send mode" : "Način rada za slanje",
    "Encryption" : "Šifriranje",
    "From address" : "S adrese",
    "mail" : "pošta",
    "Authentication method" : "Postupak autentikacije",
    "Authentication required" : "Potrebna autentikacija",
    "Server address" : "Adresa poslužitelja",
    "Port" : "Priključak",
    "Credentials" : "Vjerodajnice",
    "SMTP Username" : "Korisničko ime SMTP",
    "SMTP Password" : "Lozinka SMPT",
    "Test email settings" : "Postavke za testnu e-poštu",
    "Send email" : "Pošaljite e-poštu",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP je očigledno postavljen na strip inline doc blocks. To će nekoliko osnovnih aplikacija učiniti nedostupnima.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Uzrok tome je vjerojatno neki ubrzivač predmemoriranja kao što je Zend OPcache ilieAccelerator.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP modul 'fileinfo' nedostaje. Tolo vam preporučjemo da taj modul omogućitekako biste dobili najbolje rezultate u detekciji mime vrste.",
    "System locale can not be set to a one which supports UTF-8." : "Regionalnu shemu sustava nemoguće je postaviti na neku koja podržava UTF-8.",
    "This means that there might be problems with certain characters in file names." : "To znači da se mogu javiti problemi s određenim znakovima u datoteci.",
    "Get the apps to sync your files" : "Koristite aplikacije za sinkronizaciju svojih datoteka",
    "Show First Run Wizard again" : "Opet pokažite First Run Wizard",
    "Profile picture" : "Slika profila",
    "Upload new" : "Učitajte novu",
    "Remove image" : "Uklonite sliku",
    "Cancel" : "Odustanite",
    "Email" : "E-pošta",
    "Your email address" : "Vaša adresa e-pošte",
    "Password" : "Lozinka",
    "Unable to change your password" : "Vašu lozinku nije moguće promijeniti",
    "Current password" : "Trenutna lozinka",
    "New password" : "Nova lozinka",
    "Change password" : "Promijenite lozinku",
    "Language" : "Jezik",
    "Help translate" : "Pomozite prevesti",
    "Unlimited" : "Neograničeno",
    "Name" : "Naziv",
    "Username" : "Korisničko ime",
    "Version" : "Verzija",
    "Personal" : "Osobno",
    "Admin" : "Admin",
    "Error" : "Pogreška",
    "Show storage location" : "Prikaži mjesto pohrane",
    "Show last log in" : "Prikaži zadnje spajanje",
    "Create" : "Kreirajte",
    "Admin Recovery Password" : "Admin lozinka za oporavak",
    "Enter the recovery password in order to recover the users files during password change" : "Unesite lozinku za oporavak da biste oporavili korisničke datoteke tijekom promjene lozinke",
    "Add Group" : "Dodajte grupu",
    "Group" : "Grupa",
    "Everyone" : "Svi",
    "Admins" : "Admins",
    "Default Quota" : "Zadana kvota",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Molimo unesite kvotu za spremanje (npr: \"512 MB\" ili \"12 GB\")",
    "Other" : "Ostalo",
    "Full Name" : "Puno ime",
    "Quota" : "Kvota",
    "Storage Location" : "Mjesto za spremanje",
    "Last Login" : "Zadnja prijava",
    "change full name" : "promijenite puno ime",
    "set new password" : "postavite novu lozinku",
    "Default" : "Zadano"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
